CANopen device documentation
============================
**PZ3-i**

|              |                                |
| ------------ | ------------------------------ |
| Project File | CANopen PZ3-i.xdd              |
| File Version | 1.1                            |

<!-- TOC -->

- [CANopen device documentation](#canopen-device-documentation)
    - [Device Information](#device-information)
    - [CAN Bus Address](#can-bus-address)
    - [Supported Baud rates](#supported-baud-rates)
    - [PDO Mapping](#pdo-mapping)
        - [RPDO 0x1400](#rpdo-0x1400)
        - [TPDO 0x1800](#tpdo-0x1800)
        - [TPDO 0x1801](#tpdo-0x1801)
        - [TPDO 0x1802](#tpdo-0x1802)
    - [Communication Specific Parameters](#communication-specific-parameters)
        - [x1000 - Device type](#x1000---device-type)
        - [x1001 - Error register](#x1001---error-register)
        - [x1003 - Pre-defined error field](#x1003---pre-defined-error-field)
        - [x1005 - COB-ID SYNC message](#x1005---cob-id-sync-message)
        - [x1006 - Communication cycle period](#x1006---communication-cycle-period)
        - [x1007 - Synchronous window length](#x1007---synchronous-window-length)
        - [x1008 - Manufacturer device name](#x1008---manufacturer-device-name)
        - [x1009 - Manufacturer hardware version](#x1009---manufacturer-hardware-version)
        - [x100A - Manufacturer software version](#x100a---manufacturer-software-version)
        - [x100C - Guard Time](#x100c---guard-time)
        - [x100D - Life time factor](#x100d---life-time-factor)
        - [x1014 - COB-ID EMCY](#x1014---cob-id-emcy)
        - [x1016 - Consumer heartbeat time](#x1016---consumer-heartbeat-time)
        - [x1017 - Producer heartbeat time](#x1017---producer-heartbeat-time)
        - [x1018 - Identity](#x1018---identity)
        - [x1019 - Synchronous counter overflow value](#x1019---synchronous-counter-overflow-value)
        - [x1200 - SDO server parameter](#x1200---sdo-server-parameter)
        - [x1400 - RPDO communication parameter](#x1400---rpdo-communication-parameter)
        - [x1600 - RPDO mapping parameter](#x1600---rpdo-mapping-parameter)
        - [x1800 - TPDO communication parameter](#x1800---tpdo-communication-parameter)
        - [x1801 - TPDO communication parameter](#x1801---tpdo-communication-parameter)
        - [x1802 - TPDO communication parameter](#x1802---tpdo-communication-parameter)
        - [x1A00 - TPDO mapping parameter](#x1a00---tpdo-mapping-parameter)
        - [x1A01 - TPDO mapping parameter](#x1a01---tpdo-mapping-parameter)
        - [x1A02 - TPDO mapping parameter](#x1a02---tpdo-mapping-parameter)
    - [Manufacturer Specific Parameters](#manufacturer-specific-parameters)
        - [x2000 - Status Code](#x2000---status-code)
        - [x2001 - Error Code](#x2001---error-code)
        - [x2002 - Temperature](#x2002---temperature)
        - [x2003 - Module Present](#x2003---module-present)
        - [x2004 - Warning Code](#x2004---warning-code)
        - [x200F - Plasma Active](#x200f---plasma-active)
        - [x2010 - Plasma On](#x2010---plasma-on)
        - [x2011 - Error Reset](#x2011---error-reset)
        - [x2012 - Power Setpoint](#x2012---power-setpoint)
        - [x2020 - Plasma Parameters](#x2020---plasma-parameters)
        - [x2030 - Device Error Counters](#x2030---device-error-counters)
        - [x2031 - Device Plasma On Time](#x2031---device-plasma-on-time)
        - [x2032 - Module Error Counters](#x2032---module-error-counters)
        - [x2034 - Module Information](#x2034---module-information)
        - [x2035 - Device Version Numbers](#x2035---device-version-numbers)
        - [x2100 - Bitrate Setting](#x2100---bitrate-setting)

<!-- /TOC -->

Device Information
------------------
|              |                                |
| ------------ | ------------------------------ |
| Vendor Name  | relyon plasma GmbH             |
| Vendor ID    | 0000                           |
| Product Name | PZ3-i                          |
| Product ID   | 0000                           |
| Granularity  | 8                              |
| RPDO count   | 1                              |
| TPDO count   | 3                              |
| LSS Slave    | False                          |
| LSS Master   | False                          |

CAN Bus Address
---------------
| SW1 | SW2 | SW3 | SW4 | SW5 | SW6 | CAN Address             | SW1 | SW2 | SW3 | SW4 | SW5 | SW6 | CAN Address             |
| --- | --- | --- | --- | --- | --- | ----------------------- | --- | --- | --- | --- | --- | --- | ----------------------- |
|  0  |  0  |  0  |  0  |  0  |  0  | 0 (CANopen is disabled) |  0  |  0  |  0  |  0  |  0  |  1  | 32                      |
|  1  |  0  |  0  |  0  |  0  |  0  | 1                       |  1  |  0  |  0  |  0  |  0  |  1  | 33                      |
|  0  |  1  |  0  |  0  |  0  |  0  | 2                       |  0  |  1  |  0  |  0  |  0  |  1  | 34                      |
|  1  |  1  |  0  |  0  |  0  |  0  | 3                       |  1  |  1  |  0  |  0  |  0  |  1  | 35                      |
|  0  |  0  |  1  |  0  |  0  |  0  | 4                       |  0  |  0  |  1  |  0  |  0  |  1  | 36                      |
|  1  |  0  |  1  |  0  |  0  |  0  | 5                       |  1  |  0  |  1  |  0  |  0  |  1  | 37                      |
|  0  |  1  |  1  |  0  |  0  |  0  | 6                       |  0  |  1  |  1  |  0  |  0  |  1  | 38                      |
|  1  |  1  |  1  |  0  |  0  |  0  | 7                       |  1  |  1  |  1  |  0  |  0  |  1  | 39                      |
|  0  |  0  |  0  |  1  |  0  |  0  | 8                       |  0  |  0  |  0  |  1  |  0  |  1  | 40                      |
|  1  |  0  |  0  |  1  |  0  |  0  | 9                       |  1  |  0  |  0  |  1  |  0  |  1  | 41                      |
|  0  |  1  |  0  |  1  |  0  |  0  | 10                      |  0  |  1  |  0  |  1  |  0  |  1  | 42                      |
|  1  |  1  |  0  |  1  |  0  |  0  | 11                      |  1  |  1  |  0  |  1  |  0  |  1  | 43                      |
|  0  |  0  |  1  |  1  |  0  |  0  | 12                      |  0  |  0  |  1  |  1  |  0  |  1  | 44                      |
|  1  |  0  |  1  |  1  |  0  |  0  | 13                      |  1  |  0  |  1  |  1  |  0  |  1  | 45                      |
|  0  |  1  |  1  |  1  |  0  |  0  | 14                      |  0  |  1  |  1  |  1  |  0  |  1  | 46                      |
|  1  |  1  |  1  |  1  |  0  |  0  | 15                      |  1  |  1  |  1  |  1  |  0  |  1  | 47                      |
|  0  |  0  |  0  |  0  |  1  |  0  | 16                      |  0  |  0  |  0  |  0  |  1  |  1  | 48                      |
|  1  |  0  |  0  |  0  |  1  |  0  | 17                      |  1  |  0  |  0  |  0  |  1  |  1  | 49                      |
|  0  |  1  |  0  |  0  |  1  |  0  | 18                      |  0  |  1  |  0  |  0  |  1  |  1  | 50                      |
|  1  |  1  |  0  |  0  |  1  |  0  | 19                      |  1  |  1  |  0  |  0  |  1  |  1  | 51                      |
|  0  |  0  |  1  |  0  |  1  |  0  | 20                      |  0  |  0  |  1  |  0  |  1  |  1  | 52                      |
|  1  |  0  |  1  |  0  |  1  |  0  | 21                      |  1  |  0  |  1  |  0  |  1  |  1  | 53                      |
|  0  |  1  |  1  |  0  |  1  |  0  | 22                      |  0  |  1  |  1  |  0  |  1  |  1  | 54                      |
|  1  |  1  |  1  |  0  |  1  |  0  | 23                      |  1  |  1  |  1  |  0  |  1  |  1  | 55                      |
|  0  |  0  |  0  |  1  |  1  |  0  | 24                      |  0  |  0  |  0  |  1  |  1  |  1  | 56                      |
|  1  |  0  |  0  |  1  |  1  |  0  | 25                      |  1  |  0  |  0  |  1  |  1  |  1  | 57                      |
|  0  |  1  |  0  |  1  |  1  |  0  | 26                      |  0  |  1  |  0  |  1  |  1  |  1  | 58                      |
|  1  |  1  |  0  |  1  |  1  |  0  | 27                      |  1  |  1  |  0  |  1  |  1  |  1  | 59                      |
|  0  |  0  |  1  |  1  |  1  |  0  | 28                      |  0  |  0  |  1  |  1  |  1  |  1  | 60                      |
|  1  |  0  |  1  |  1  |  1  |  0  | 29                      |  1  |  0  |  1  |  1  |  1  |  1  | 61                      |
|  0  |  1  |  1  |  1  |  1  |  0  | 30                      |  0  |  1  |  1  |  1  |  1  |  1  | 62                      |
|  1  |  1  |  1  |  1  |  1  |  0  | 31                      |  1  |  1  |  1  |  1  |  1  |  1  | 63                      |

Supported Baud rates
--------------------
* [ ] 10 kBit/s
* [ ] 20 kBit/s
* [ ] 50 kBit/s
* [x] 125 kBit/s
* [x] 250 kBit/s
* [x] 500 kBit/s
* [x] 800 kBit/s
* [x] 1000 kBit/s
* [ ] auto


PDO Mapping
-----------

### RPDO 0x1400
|              |                                                               |
| ------------ | ------------------------------------------------------------- |
| COB_ID       | $NODEID+0x200                                                 |
| Transmission | type=255                                                      |
|   0x20100008 | Plasma On                                                     |
|   0x20120008 | Power Setpoint                                                |
|   0x20110008 | Error Reset                                                   |


### TPDO 0x1800
|              |                                                               |
| ------------ | ------------------------------------------------------------- |
| COB_ID       | $NODEID+0x180                                                 |
| Transmission | type=255; inhibit-time=0; event-timer=0; SYNC-start-value=0   |
|   0x20000008 | Status Code                                                   |
|   0x20010008 | Error Code                                                    |
|   0x20020008 | Temperature                                                   |
|   0x20120008 | Power Setpoint                                                |
|   0x200F0008 | Plasma Active                                                 |
|   0x20030008 | Module Present                                                |


### TPDO 0x1801
|              |                                                               |
| ------------ | ------------------------------------------------------------- |
| COB_ID       | $NODEID+0x280                                                 |
| Transmission | type=255; inhibit-time=0; event-timer=0; SYNC-start-value=0   |
|   0x20200110 | Plasma Parameters (Frequency Actual)                          |
|   0x20200510 | Plasma Parameters (Phase Actual)                              |
|   0x20200610 | Plasma Parameters (Impedance Actual)                          |


### TPDO 0x1802
|              |                                                               |
| ------------ | ------------------------------------------------------------- |
| COB_ID       | $NODEID+0x380                                                 |
| Transmission | type=255; inhibit-time=0; event-timer=0; SYNC-start-value=0   |
|   0x20200210 | Plasma Parameters (Power Actual)                              |
|   0x20200310 | Plasma Parameters (Voltage Actual)                            |
|   0x20200410 | Plasma Parameters (Current Actual)                            |


Communication Specific Parameters
---------------------------------

### 0x1000 - Device type
| Object Type | Count Label    | Storage Group  |
| ----------- | -------------- | -------------- |
| VAR         | NMT            | PERSIST_COMM   |

| Data Type               | SDO | PDO | SRDO | Default Value                   |
| ----------------------- | --- | --- | ---- | ------------------------------- |
| UNSIGNED32              | ro  | no  | no   | 0x00000000                      |

* bit 16-31: Additional information
* bit 0-15: Device profile number

### 0x1001 - Error register
| Object Type | Count Label    | Storage Group  |
| ----------- | -------------- | -------------- |
| VAR         | EM             | RAM            |

| Data Type               | SDO | PDO | SRDO | Default Value                   |
| ----------------------- | --- | --- | ---- | ------------------------------- |
| UNSIGNED8               | ro  | no  | no   | 0x00                            |

* bit 7: manufacturer specific (not used)
* bit 6: Reserved (always 0)
* bit 5: device profile specific (not used)
* bit 4: communication error (overrun, error state)
* bit 3: temperature (not used)
* bit 2: voltage (not used)
* bit 1: current (not used)
* bit 0: generic error (see "Error Code" parameter for more information)

### 0x1003 - Pre-defined error field
| Object Type | Count Label    | Storage Group  |
| ----------- | -------------- | -------------- |
| ARRAY       |                | RAM            |

| Sub  | Name                  | Data Type  | SDO | PDO | SRDO | Default Value |
| ---- | --------------------- | ---------- | --- | --- | ---- | ------------- |
| 0x00 | Number of errors      | UNSIGNED8  | rw  | no  | no   |               |
| 0x01 | Standard error field  | UNSIGNED32 | ro  | no  | no   |               |
| 0x02 | Standard error field  | UNSIGNED32 | ro  | no  | no   |               |
| 0x03 | Standard error field  | UNSIGNED32 | ro  | no  | no   |               |
| 0x04 | Standard error field  | UNSIGNED32 | ro  | no  | no   |               |
| 0x05 | Standard error field  | UNSIGNED32 | ro  | no  | no   |               |
| 0x06 | Standard error field  | UNSIGNED32 | ro  | no  | no   |               |
| 0x07 | Standard error field  | UNSIGNED32 | ro  | no  | no   |               |
| 0x08 | Standard error field  | UNSIGNED32 | ro  | no  | no   |               |
| 0x09 | Standard error field  | UNSIGNED32 | ro  | no  | no   |               |
| 0x0A | Standard error field  | UNSIGNED32 | ro  | no  | no   |               |
| 0x0B | Standard error field  | UNSIGNED32 | ro  | no  | no   |               |
| 0x0C | Standard error field  | UNSIGNED32 | ro  | no  | no   |               |
| 0x0D | Standard error field  | UNSIGNED32 | ro  | no  | no   |               |
| 0x0E | Standard error field  | UNSIGNED32 | ro  | no  | no   |               |
| 0x0F | Standard error field  | UNSIGNED32 | ro  | no  | no   |               |
| 0x10 | Standard error field  | UNSIGNED32 | ro  | no  | no   |               |

* Sub Index 0: Contains number of actual errors. 0 can be written to clear error history.
* sub-index 1 and above:
  * bit 16-31: Manufacturer specific additional information
  * bit 0-15: Error code as transmited in the Emergency object

### 0x1005 - COB-ID SYNC message
| Object Type | Count Label    | Storage Group  |
| ----------- | -------------- | -------------- |
| VAR         | SYNC           | PERSIST_COMM   |

| Data Type               | SDO | PDO | SRDO | Default Value                   |
| ----------------------- | --- | --- | ---- | ------------------------------- |
| UNSIGNED32              | ro  | no  | no   | 0x00000080                      |

* bit 31: set to 0
* bit 30: If set, CANopen device generates SYNC object
* bit 11-29: set to 0
* bit 0-10: 11-bit CAN-ID

### 0x1006 - Communication cycle period
| Object Type | Count Label    | Storage Group  |
| ----------- | -------------- | -------------- |
| VAR         | SYNC_PROD      | PERSIST_COMM   |

| Data Type               | SDO | PDO | SRDO | Default Value                   |
| ----------------------- | --- | --- | ---- | ------------------------------- |
| UNSIGNED32              | ro  | no  | no   | 0                               |

Period of SYNC transmission in µs (0 = transmission disabled).

### 0x1007 - Synchronous window length
| Object Type | Count Label    | Storage Group  |
| ----------- | -------------- | -------------- |
| VAR         |                | RAM            |

| Data Type               | SDO | PDO | SRDO | Default Value                   |
| ----------------------- | --- | --- | ---- | ------------------------------- |
| UNSIGNED32              | rw  | no  | no   | 0                               |

Synchronous window leghth in µs (0 = not used). All synchronous PDOs must be transmitted within this time window.

### 0x1008 - Manufacturer device name
| Object Type | Count Label    | Storage Group  |
| ----------- | -------------- | -------------- |
| VAR         |                | PERSIST_COMM   |

| Data Type               | SDO | PDO | SRDO | Default Value                   |
| ----------------------- | --- | --- | ---- | ------------------------------- |
| VISIBLE_STRING          | ro  | no  | no   | PZ3-i                           |

### 0x1009 - Manufacturer hardware version
| Object Type | Count Label    | Storage Group  |
| ----------- | -------------- | -------------- |
| VAR         |                | PERSIST_COMM   |

| Data Type               | SDO | PDO | SRDO | Default Value                   |
| ----------------------- | --- | --- | ---- | ------------------------------- |
| VISIBLE_STRING          | ro  | no  | no   | V4-i                            |

### 0x100A - Manufacturer software version
| Object Type | Count Label    | Storage Group  |
| ----------- | -------------- | -------------- |
| VAR         |                | PERSIST_COMM   |

| Data Type               | SDO | PDO | SRDO | Default Value                   |
| ----------------------- | --- | --- | ---- | ------------------------------- |
| VISIBLE_STRING          | ro  | no  | no   | 2.0                             |

### 0x100C - Guard Time
| Object Type | Count Label    | Storage Group  |
| ----------- | -------------- | -------------- |
| VAR         |                | RAM            |

| Data Type               | SDO | PDO | SRDO | Default Value                   |
| ----------------------- | --- | --- | ---- | ------------------------------- |
| UNSIGNED16              | ro  | no  | no   | 0                               |

The objects at index 100Ch and 100Dh shall indicate the configured guard time respectively the life time factor. The life time factor multiplied with the guard time gives the life time for the life guarding protocol.

The value shall be given in multiple of ms. The value of 0000h shall disable the life guarding.

This value must be set to 0! Node Guarding with remote frames is not supported. Plese use the Heartbeat protocol.

### 0x100D - Life time factor
| Object Type | Count Label    | Storage Group  |
| ----------- | -------------- | -------------- |
| VAR         |                | RAM            |

| Data Type               | SDO | PDO | SRDO | Default Value                   |
| ----------------------- | --- | --- | ---- | ------------------------------- |
| UNSIGNED8               | ro  | no  | no   | 0                               |

The life time factor multiplied with the guard time gives the life time for the life guarding protocol.

The value of 00h shall disable the life guarding.

This value must be set to 0! Node Guarding with remote frames is not supported. Plese use the Heartbeat protocol.

### 0x1014 - COB-ID EMCY
| Object Type | Count Label    | Storage Group  |
| ----------- | -------------- | -------------- |
| VAR         | EM_PROD        | RAM            |

| Data Type               | SDO | PDO | SRDO | Default Value                   |
| ----------------------- | --- | --- | ---- | ------------------------------- |
| UNSIGNED32              | rw  | no  | no   | $NODEID+0x80                    |

* bit 31: If set, EMCY does NOT exist / is NOT valid
* bit 11-30: set to 0
* bit 0-10: 11-bit CAN-ID

### 0x1016 - Consumer heartbeat time
| Object Type | Count Label    | Storage Group  |
| ----------- | -------------- | -------------- |
| ARRAY       | HB_CONS        | PERSIST_COMM   |

| Sub  | Name                  | Data Type  | SDO | PDO | SRDO | Default Value |
| ---- | --------------------- | ---------- | --- | --- | ---- | ------------- |
| 0x00 | Highest sub-index supported| UNSIGNED8  | ro  | no  | no   | 1          |
| 0x01 | Consumer heartbeat time| UNSIGNED32 | rw  | no  | no   | 0x00000000    |

Consumer Heartbeat Time:
  * bit 24-31: set to 0
  * bit 16-23: Node ID of the monitored node. If 0 or greater than 127, sub-entry is not used.
  * bit 0-15: Heartbeat time in ms (if 0, sub-intry is not used). Value should be higher than the corresponding producer heartbeat time.

### 0x1017 - Producer heartbeat time
| Object Type | Count Label    | Storage Group  |
| ----------- | -------------- | -------------- |
| VAR         | HB_PROD        | RAM            |

| Data Type               | SDO | PDO | SRDO | Default Value                   |
| ----------------------- | --- | --- | ---- | ------------------------------- |
| UNSIGNED16              | rw  | no  | no   | 0                               |

Heartbeat producer time in ms (0 = disable transmission).

### 0x1018 - Identity
| Object Type | Count Label    | Storage Group  |
| ----------- | -------------- | -------------- |
| RECORD      |                | PERSIST_COMM   |

| Sub  | Name                  | Data Type  | SDO | PDO | SRDO | Default Value |
| ---- | --------------------- | ---------- | --- | --- | ---- | ------------- |
| 0x00 | Highest sub-index supported| UNSIGNED8  | ro  | no  | no   | 4          |
| 0x01 | Vendor-ID             | UNSIGNED32 | ro  | no  | no   | 0x00000000    |
| 0x02 | Product code          | UNSIGNED32 | ro  | no  | no   | 0x00000000    |
| 0x03 | Revision number       | UNSIGNED32 | ro  | no  | no   | 0x00010000    |
| 0x04 | Serial number         | UNSIGNED32 | ro  | no  | no   | 0x00000000    |

* Vendor-ID, assigned by CiA
* Product code, manufacturer specific
* Revision number:
  * bit 16-31: Major revision number (CANopen behavior has changed)
  * bit 0-15: Minor revision num. (CANopen behavior has not changed)
* Serial number, manufacturer specific

### 0x1019 - Synchronous counter overflow value
| Object Type | Count Label    | Storage Group  |
| ----------- | -------------- | -------------- |
| VAR         |                | RAM            |

| Data Type               | SDO | PDO | SRDO | Default Value                   |
| ----------------------- | --- | --- | ---- | ------------------------------- |
| UNSIGNED8               | rw  | no  | no   | 0                               |

* Value 0: SYNC message is transmitted with data length 0.
* Value 1: reserved.
* Value 2-240: SYNC message has one data byte, which contains the counter.
* Value 241-255: reserved.

### 0x1200 - SDO server parameter
| Object Type | Count Label    | Storage Group  |
| ----------- | -------------- | -------------- |
| RECORD      | SDO_SRV        | RAM            |

| Sub  | Name                  | Data Type  | SDO | PDO | SRDO | Default Value |
| ---- | --------------------- | ---------- | --- | --- | ---- | ------------- |
| 0x00 | Highest sub-index supported| UNSIGNED8  | ro  | no  | no   | 2             |
| 0x01 | COB-ID client to server (rx)| UNSIGNED32 | ro  | no  | no   | $NODEID+0x600 |
| 0x02 | COB-ID server to client (tx)| UNSIGNED32 | ro  | no  | no   | $NODEID+0x580 |

Sub-indexes 1 and 2:
* bit 11-31: set to 0
* bit 0-10: 11-bit CAN-ID

### 0x1400 - RPDO communication parameter
| Object Type | Count Label    | Storage Group  |
| ----------- | -------------- | -------------- |
| RECORD      | RPDO           | RAM            |

| Sub  | Name                  | Data Type  | SDO | PDO | SRDO | Default Value |
| ---- | --------------------- | ---------- | --- | --- | ---- | ------------- |
| 0x00 | max sub-index         | UNSIGNED8  | ro  | no  | no   | 6             |
| 0x01 | COB-ID used by RPDO   | UNSIGNED32 | ro  | no  | no   | $NODEID+0x200 |
| 0x02 | transmission type     | UNSIGNED8  | ro  | t   | no   | 255           |

### 0x1600 - RPDO mapping parameter
| Object Type | Count Label    | Storage Group  |
| ----------- | -------------- | -------------- |
| RECORD      |                | RAM            |

| Sub  | Name                  | Data Type  | SDO | PDO | SRDO | Default Value |
| ---- | --------------------- | ---------- | --- | --- | ---- | ------------- |
| 0x00 | Number of mapped objects| UNSIGNED8  | ro  | no  | no   | 3             |
| 0x01 | Mapped object 1       | UNSIGNED32 | ro  | no  | no   | 0x20100008    |
| 0x02 | Mapped object 2       | UNSIGNED32 | ro  | no  | no   | 0x20120008    |
| 0x03 | Mapped object 3       | UNSIGNED32 | ro  | no  | no   | 0x20110008    |

### 0x1800 - TPDO communication parameter
| Object Type | Count Label    | Storage Group  |
| ----------- | -------------- | -------------- |
| RECORD      | TPDO           | RAM            |

| Sub  | Name                  | Data Type  | SDO | PDO | SRDO | Default Value |
| ---- | --------------------- | ---------- | --- | --- | ---- | ------------- |
| 0x00 | max sub-index         | UNSIGNED8  | ro  | no  | no   | 6             |
| 0x01 | COB-ID used by TPDO   | UNSIGNED32 | ro  | no  | no   | $NODEID+0x180 |
| 0x02 | transmission type     | UNSIGNED8  | ro  | no  | no   | 255           |
| 0x03 | inhibit time          | UNSIGNED16 | rw  | no  | no   | 0             |
| 0x04 | compatibility entry   | UNSIGNED8  | rw  | no  | no   | 0             |
| 0x05 | event timer           | UNSIGNED16 | rw  | no  | no   | 0             |
| 0x06 | SYNC start value      | UNSIGNED8  | rw  | no  | no   | 0             |

### 0x1801 - TPDO communication parameter
| Object Type | Count Label    | Storage Group  |
| ----------- | -------------- | -------------- |
| RECORD      | TPDO           | RAM            |

| Sub  | Name                  | Data Type  | SDO | PDO | SRDO | Default Value |
| ---- | --------------------- | ---------- | --- | --- | ---- | ------------- |
| 0x00 | max sub-index         | UNSIGNED8  | ro  | no  | no   | 6             |
| 0x01 | COB-ID used by TPDO   | UNSIGNED32 | ro  | no  | no   | $NODEID+0x280 |
| 0x02 | transmission type     | UNSIGNED8  | ro  | no  | no   | 255           |
| 0x03 | inhibit time          | UNSIGNED16 | rw  | no  | no   | 0             |
| 0x04 | compatibility entry   | UNSIGNED8  | rw  | no  | no   | 0             |
| 0x05 | event timer           | UNSIGNED16 | rw  | no  | no   | 0             |
| 0x06 | SYNC start value      | UNSIGNED8  | rw  | no  | no   | 0             |

### 0x1802 - TPDO communication parameter
| Object Type | Count Label    | Storage Group  |
| ----------- | -------------- | -------------- |
| RECORD      | TPDO           | RAM            |

| Sub  | Name                  | Data Type  | SDO | PDO | SRDO | Default Value |
| ---- | --------------------- | ---------- | --- | --- | ---- | ------------- |
| 0x00 | max sub-index         | UNSIGNED8  | ro  | no  | no   | 6             |
| 0x01 | COB-ID used by TPDO   | UNSIGNED32 | ro  | no  | no   | $NODEID+0x380 |
| 0x02 | transmission type     | UNSIGNED8  | ro  | no  | no   | 255           |
| 0x03 | inhibit time          | UNSIGNED16 | rw  | no  | no   | 0             |
| 0x04 | compatibility entry   | UNSIGNED8  | rw  | no  | no   | 0             |
| 0x05 | event timer           | UNSIGNED16 | rw  | no  | no   | 0             |
| 0x06 | SYNC start value      | UNSIGNED8  | rw  | no  | no   | 0             |

### 0x1A00 - TPDO mapping parameter
| Object Type | Count Label    | Storage Group  |
| ----------- | -------------- | -------------- |
| RECORD      |                | RAM            |

| Sub  | Name                  | Data Type  | SDO | PDO | SRDO | Default Value |
| ---- | --------------------- | ---------- | --- | --- | ---- | ------------- |
| 0x00 | Number of mapped objects| UNSIGNED8  | ro  | no  | no   | 6             |
| 0x01 | Mapped object 1       | UNSIGNED32 | ro  | no  | no   | 0x20000008    |
| 0x02 | Mapped object 2       | UNSIGNED32 | ro  | no  | no   | 0x20010008    |
| 0x03 | Mapped object 3       | UNSIGNED32 | ro  | no  | no   | 0x20020008    |
| 0x04 | Mapped object 4       | UNSIGNED32 | ro  | no  | no   | 0x20120008    |
| 0x05 | Mapped object 5       | UNSIGNED32 | ro  | no  | no   | 0x200F0008    |
| 0x06 | Mapped object 6       | UNSIGNED32 | ro  | no  | no   | 0x20030008    |

### 0x1A01 - TPDO mapping parameter
| Object Type | Count Label    | Storage Group  |
| ----------- | -------------- | -------------- |
| RECORD      |                | RAM            |

| Sub  | Name                  | Data Type  | SDO | PDO | SRDO | Default Value |
| ---- | --------------------- | ---------- | --- | --- | ---- | ------------- |
| 0x00 | Number of mapped objects| UNSIGNED8  | ro  | no  | no   | 3             |
| 0x01 | Mapped object 1       | UNSIGNED32 | ro  | no  | no   | 0x20200110    |
| 0x02 | Mapped object 2       | UNSIGNED32 | ro  | no  | no   | 0x20200510    |
| 0x03 | Mapped object 3       | UNSIGNED32 | ro  | no  | no   | 0x20200610    |

### 0x1A02 - TPDO mapping parameter
| Object Type | Count Label    | Storage Group  |
| ----------- | -------------- | -------------- |
| RECORD      |                | RAM            |

| Sub  | Name                  | Data Type  | SDO | PDO | SRDO | Default Value |
| ---- | --------------------- | ---------- | --- | --- | ---- | ------------- |
| 0x00 | Number of mapped objects| UNSIGNED8  | ro  | no  | no   | 3             |
| 0x01 | Mapped object 1       | UNSIGNED32 | ro  | no  | no   | 0x20200210    |
| 0x02 | Mapped object 2       | UNSIGNED32 | ro  | no  | no   | 0x20200310    |
| 0x03 | Mapped object 3       | UNSIGNED32 | ro  | no  | no   | 0x20200410    |

Manufacturer Specific Parameters
--------------------------------

### 0x2000 - Status Code
| Object Type | Count Label    | Storage Group  |
| ----------- | -------------- | -------------- |
| VAR         |                | RAM            |

| Data Type               | SDO | PDO | SRDO | Default Value                   |
| ----------------------- | --- | --- | ---- | ------------------------------- |
| UNSIGNED8               | ro  | t   | no   | 0                               |

Operation state of the plasma generator
* 0 = Nomal: no warning and no error
* 1 = Warning: at least one warning. Reset automatically when state changes
* 2 = Error :at least one error. Reset by writing 1 to 0x2011 necessary


### 0x2001 - Error Code
| Object Type | Count Label    | Storage Group  |
| ----------- | -------------- | -------------- |
| VAR         |                | RAM            |

| Data Type               | SDO | PDO | SRDO | Default Value                   |
| ----------------------- | --- | --- | ---- | ------------------------------- |
| UNSIGNED8               | ro  | t   | no   | 0                               |

Errors specific to the plasma generator
* 0x00 = NO ERROR
* 0x01 = PLASMA ERROR: Plasma generator was shutdown due to an inadmissible condition.
* 0x02 = TEMPERATURE ERROR: Plasma generator was shutdown due to an inadmissible temperature.
* 0x04 = MODULE ERROR: Module EEPROM contains invalid data.
* 0x08 = COMMUNICATION ERROR: Internal connetion error

A combination (logical or) is possible

### 0x2002 - Temperature
| Object Type | Count Label    | Storage Group  |
| ----------- | -------------- | -------------- |
| VAR         |                | RAM            |

| Data Type               | SDO | PDO | SRDO | Default Value                   |
| ----------------------- | --- | --- | ---- | ------------------------------- |
| INTEGER8                | ro  | t   | no   | 0                               |

Temerature of the plasma output driver in °C

### 0x2003 - Module Present
| Object Type | Count Label    | Storage Group  |
| ----------- | -------------- | -------------- |
| VAR         |                | RAM            |

| Data Type               | SDO | PDO | SRDO | Default Value                   |
| ----------------------- | --- | --- | ---- | ------------------------------- |
| UNSIGNED8               | ro  | t   | no   | 0                               |

0 = no Module inserted
1 = Module inserted

### 0x2004 - Warning Code
| Object Type | Count Label    | Storage Group  |
| ----------- | -------------- | -------------- |
| VAR         |                | RAM            |

| Data Type               | SDO | PDO | SRDO | Default Value                   |
| ----------------------- | --- | --- | ---- | ------------------------------- |
| UNSIGNED8               | ro  | no  | no   | 0                               |

Warnings specific to the plasma generator
* 0x01: WARNING_PLASMA: driver stage parameters for plasma generation is not in optimal range
* 0x02: WARNING_TEMPERATURE: device temperature is getting too high

A combination (logical or) is possible

### 0x200F - Plasma Active
| Object Type | Count Label    | Storage Group  |
| ----------- | -------------- | -------------- |
| VAR         |                | RAM            |

| Data Type               | SDO | PDO | SRDO | Default Value                   |
| ----------------------- | --- | --- | ---- | ------------------------------- |
| UNSIGNED8               | rw  | tr  | no   | 0                               |

Controll register for turning the plasma generator on and off

Writing a value of 1 or greater will turn the plasma generator on.<br />
Writing a 0 will turn the plasma generator off


### 0x2010 - Plasma On
| Object Type | Count Label    | Storage Group  |
| ----------- | -------------- | -------------- |
| VAR         |                | RAM            |

| Data Type               | SDO | PDO | SRDO | Default Value                   |
| ----------------------- | --- | --- | ---- | ------------------------------- |
| UNSIGNED8               | rw  | tr  | no   | 0                               |

Controll register for turning the plasma generator on and off

Writing a value of 1 or greater will turn the plasma generator on.<br />
Writing a 0 will turn the plasma generator off


### 0x2011 - Error Reset
| Object Type | Count Label    | Storage Group  |
| ----------- | -------------- | -------------- |
| VAR         |                | RAM            |

| Data Type               | SDO | PDO | SRDO | Default Value                   |
| ----------------------- | --- | --- | ---- | ------------------------------- |
| UNSIGNED8               | wo  | r   | no   | 0                               |

Writing 1 or greater will reset any error state of the plasma generator

This field is **WRITE ONLY**!


### 0x2012 - Power Setpoint
| Object Type | Count Label    | Storage Group  |
| ----------- | -------------- | -------------- |
| VAR         |                | RAM            |

| Data Type               | SDO | PDO | SRDO | Default Value                   |
| ----------------------- | --- | --- | ---- | ------------------------------- |
| UNSIGNED8               | rw  | tr  | no   | 100                             |

Power setting of the plasma generator in %.<br />
The minimum value is defined by the module.


### 0x2020 - Plasma Parameters
| Object Type | Count Label    | Storage Group  |
| ----------- | -------------- | -------------- |
| RECORD      |                | RAM            |

| Sub  | Name                  | Data Type  | SDO | PDO | SRDO | Default Value |
| ---- | --------------------- | ---------- | --- | --- | ---- | ------------- |
| 0x00 | Highest sub-index supported| UNSIGNED8  | ro  | no  | no   | 6          |
| 0x01 | Frequency Actual      | UNSIGNED16 | ro  | t   | no   | 0             |
| 0x02 | Power Actual          | UNSIGNED16 | ro  | t   | no   | 0             |
| 0x03 | Voltage Actual        | UNSIGNED16 | ro  | t   | no   | 0             |
| 0x04 | Current Actual        | UNSIGNED16 | ro  | t   | no   | 0             |
| 0x05 | Phase Actual          | UNSIGNED16 | ro  | t   | no   | 0             |
| 0x06 | Impedance Actual      | UNSIGNED16 | ro  | t   | no   | 0             |

Parameters of the plasma driver.<br />
Updated every 0.5 seconds when plasma generator is on

Frequency of the Ceraplas element in x10Hz
Magnitide of the Phaseangle between m°

### 0x2030 - Device Error Counters
| Object Type | Count Label    | Storage Group  |
| ----------- | -------------- | -------------- |
| RECORD      |                | RAM            |

| Sub  | Name                  | Data Type  | SDO | PDO | SRDO | Default Value |
| ---- | --------------------- | ---------- | --- | --- | ---- | ------------- |
| 0x00 | Highest sub-index supported| UNSIGNED8  | ro  | no  | no   | 4          |
| 0x01 | Voltage Errors        | UNSIGNED32 | ro  | no  | no   | 0             |
| 0x02 | Current Errors        | UNSIGNED32 | ro  | no  | no   | 0             |
| 0x03 | Frequency Errors      | UNSIGNED32 | ro  | no  | no   | 0             |
| 0x04 | Temperature Errors    | UNSIGNED32 | ro  | no  | no   | 0             |

Error counters for the plasma geneator device

### 0x2031 - Device Plasma On Time
| Object Type | Count Label    | Storage Group  |
| ----------- | -------------- | -------------- |
| VAR         |                | RAM            |

| Data Type               | SDO | PDO | SRDO | Default Value                   |
| ----------------------- | --- | --- | ---- | ------------------------------- |
| UNSIGNED32              | ro  | no  | no   | 0                               |

Time the device spend in plasma generation mode

### 0x2032 - Module Error Counters
| Object Type | Count Label    | Storage Group  |
| ----------- | -------------- | -------------- |
| RECORD      |                | RAM            |

| Sub  | Name                  | Data Type  | SDO | PDO | SRDO | Default Value |
| ---- | --------------------- | ---------- | --- | --- | ---- | ------------- |
| 0x00 | Highest sub-index supported| UNSIGNED8  | ro  | no  | no   | 4          |
| 0x01 | Voltage Errors        | UNSIGNED32 | ro  | no  | no   | 0             |
| 0x02 | Current Errors        | UNSIGNED32 | ro  | no  | no   | 0             |
| 0x03 | Frequency Errors      | UNSIGNED32 | ro  | no  | no   | 0             |
| 0x04 | Temperature Errors    | UNSIGNED32 | ro  | no  | no   | 0             |

Error counters for the plasma geneator module

### 0x2034 - Module Information
| Object Type | Count Label    | Storage Group  |
| ----------- | -------------- | -------------- |
| RECORD      |                | RAM            |

| Sub  | Name                  | Data Type  | SDO | PDO | SRDO | Default Value |
| ---- | --------------------- | ---------- | --- | --- | ---- | ------------- |
| 0x00 | Highest sub-index supported| UNSIGNED8  | ro  | no  | no   | 5          |
| 0x01 | Name                  | VISIBLE_STRING (len=15)| ro  | no  | no   |               |
| 0x02 | Serial Number         | UNSIGNED32 | ro  | no  | no   | 0             |
| 0x03 | Max Power             | UNSIGNED16 | ro  | no  | no   | 0             |
| 0x04 | Min Power Setting     | UNSIGNED8  | ro  | no  | no   | 100           |
| 0x05 | Plasma On Time        | UNSIGNED32 | ro  | no  | no   | 0             |

General infromation about the plasma module.
* Label of the inserted module
* Serial number of the inserted PZ3 module
* Maximum power of the Module in mW
* Minimum power settingh in %
* Time the module spend in plasma generation mode

Maximum power of the Module in mW
Minimum power settingh in %

### 0x2035 - Device Version Numbers
| Object Type | Count Label    | Storage Group  |
| ----------- | -------------- | -------------- |
| RECORD      |                | RAM            |

| Sub  | Name                  | Data Type  | SDO | PDO | SRDO | Default Value |
| ---- | --------------------- | ---------- | --- | --- | ---- | ------------- |
| 0x00 | Highest sub-index supported| UNSIGNED8  | ro  | no  | no   | 3          |
| 0x01 | HW Version            | VISIBLE_STRING| ro  | no  | no   | 2.0           |
| 0x02 | SW Version            | VISIBLE_STRING| ro  | no  | no   | 4-i           |
| 0x03 | CAN Version           | VISIBLE_STRING| ro  | no  | no   | 1.0           |

Version Numbers of Firmware and Hardware

### 0x2100 - Bitrate Setting
| Object Type | Count Label    | Storage Group  |
| ----------- | -------------- | -------------- |
| VAR         |                | RAM            |

| Data Type               | SDO | PDO | SRDO | Default Value                   |
| ----------------------- | --- | --- | ---- | ------------------------------- |
| UNSIGNED16              | rw  | no  | no   | 500                             |

Configure the desired CANopen bitrate of the device.
The new bitrate gets applied with the next power cycle.
